@@ -60,7 +60,10 @@ struct _PlannerTaskTreePriv {
 	PlannerWindow  *main_window;
 
 	gboolean        highlight_critical;
-	
+
+	/* Nonstandard days visualization */
+	gboolean        nonstandard_days;
+
 	/* Keep the dialogs here so that we can just raise the dialog if it's
 	 * opened twice for the same task.
 	 */
@@ -95,7 +98,7 @@ static void        task_tree_finalize                  (GObject              *ob
 static void        task_tree_setup_tree_view           (GtkTreeView          *tree,
 							MrpProject           *project,
 							PlannerGanttModel    *model);
-static void        task_tree_add_column                (GtkTreeView          *tree,
+static void        task_tree_add_column                (PlannerTaskTree      *tree,
 							gint                  column,
 							const gchar          *title);
 static void        task_tree_name_data_func            (GtkTreeViewColumn    *tree_column,
@@ -515,7 +518,9 @@ task_cmd_remove_undo (PlannerCmd *cmd_base)
 
 	child_parent = planner_gantt_model_get_indent_task_target (model, cmd->task);
 
-	if (cmd->children != NULL) task_cmd_restore_children (cmd);
+	if (cmd->children != NULL) {
+		task_cmd_restore_children (cmd);
+	}
 
 	task_cmd_restore_relations (cmd);
 	task_cmd_restore_assignments (cmd);
@@ -1356,7 +1361,6 @@ task_tree_wbs_data_func (GtkTreeViewColumn *tree_column,
 			    iter,
 			    COL_WBS, &str,
 			    -1);
-
 	g_object_set (cell,
 		      "text", str,
 		      NULL);
@@ -2115,6 +2119,8 @@ task_tree_property_added (MrpProject      *project,
 	gtk_tree_view_column_set_title (col, 
 					mrp_property_get_label (property));
 
+	g_object_set_data (G_OBJECT (col), "custom", GINT_TO_POINTER (TRUE));
+	
 	g_hash_table_insert (priv->property_to_column, property, col);
 	
 	data->property = property;
@@ -2249,33 +2255,44 @@ task_tree_setup_tree_view (GtkTreeView       *tree,
 	}
 }
 
+/* Note: this is not ideal, it emits the signal as soon as the width is changed
+ * during the resize. We should only emit it when the resizing is done.
+ */
 static void
-task_tree_add_column (GtkTreeView *tree,
+task_tree_column_notify_width_cb (GtkWidget       *column,
+				  GParamSpec      *spec,
+				  PlannerTaskTree *tree)
+{
+	if (GTK_WIDGET_REALIZED (tree)) {
+		g_signal_emit_by_name (tree, "columns-changed");
+	}
+}
+
+static void
+task_tree_add_column (PlannerTaskTree *tree,
 		      gint         column,
 		      const gchar *title)
 {
 	GtkTreeViewColumn *col;
 	GtkCellRenderer   *cell;
+	gboolean           expander = FALSE;
 
 	switch (column) {
 	case COL_WBS:
 		cell = gtk_cell_renderer_text_new ();
-
+		
 		col = gtk_tree_view_column_new_with_attributes (title,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_wbs_data_func,
-							 tree, NULL);
+							 GTK_TREE_VIEW (tree), NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_wbs_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-		
+		g_object_set_data (G_OBJECT (col), "id", "wbs");
 		gtk_tree_view_column_set_resizable (col, TRUE);
 		gtk_tree_view_column_set_min_width (col, 50);
-		gtk_tree_view_append_column (tree, col);
 		break;
 
 	case COL_NAME:
@@ -2285,7 +2302,7 @@ task_tree_add_column (GtkTreeView *tree,
 		g_signal_connect (cell,
 				  "edited",
 				  G_CALLBACK (task_tree_name_edited),
-				  tree);
+				  GTK_TREE_VIEW (tree));
 
 		col = gtk_tree_view_column_new_with_attributes (title,
 								cell,
@@ -2293,18 +2310,14 @@ task_tree_add_column (GtkTreeView *tree,
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_name_data_func,
-							 tree, NULL);
+							 GTK_TREE_VIEW (tree), NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_name_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
+		g_object_set_data (G_OBJECT (col), "id", "name");
 		
 		gtk_tree_view_column_set_resizable (col, TRUE);
 		gtk_tree_view_column_set_min_width (col, 100);
-		gtk_tree_view_append_column (tree, col);
-		gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
-		gtk_tree_view_set_expander_column (tree, col);
-                                             
+		expander = TRUE;
 		break;
 
 	case COL_START:
@@ -2312,11 +2325,11 @@ task_tree_add_column (GtkTreeView *tree,
 		g_signal_connect (cell,
 				  "edited",
 				  G_CALLBACK (task_tree_start_edited),
-				  tree);
+				  GTK_TREE_VIEW (tree));
 		g_signal_connect (cell,
 				  "show-popup",
 				  G_CALLBACK (task_tree_start_show_popup),
-				  tree);
+				  GTK_TREE_VIEW (tree));
 		
 		col = gtk_tree_view_column_new_with_attributes (title,
 								cell,
@@ -2326,13 +2339,10 @@ task_tree_add_column (GtkTreeView *tree,
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_start_data_func,
-							 tree, NULL);
+							 GTK_TREE_VIEW (tree), NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_start_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-		
-		gtk_tree_view_append_column (tree, col);
+		g_object_set_data (G_OBJECT (col), "id", "start");
 		break;
 		
 	case COL_DURATION:
@@ -2341,21 +2351,20 @@ task_tree_add_column (GtkTreeView *tree,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_min_width (col, 70);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_duration_data_func,
-							 tree,
+							 GTK_TREE_VIEW (tree),
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_duration_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
+		g_object_set_data (G_OBJECT (col), "id", "duration");
+
 		g_signal_connect (cell,
 				  "edited",
 				  G_CALLBACK (task_tree_duration_edited),
-				  tree);
-		
-		gtk_tree_view_append_column (tree, col);
+				  GTK_TREE_VIEW (tree));
 		break;
 
 	case COL_WORK:
@@ -2364,22 +2373,20 @@ task_tree_add_column (GtkTreeView *tree,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_min_width (col, 70);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_work_data_func,
-							 tree,
+							 GTK_TREE_VIEW (tree),
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_work_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
+		g_object_set_data (G_OBJECT (col), "id", "work");
 
 		g_signal_connect (cell,
 				  "edited",
 				  G_CALLBACK (task_tree_work_edited),
-				  tree);
-		
-		gtk_tree_view_append_column (tree, col);
+				  GTK_TREE_VIEW (tree));
 		break;
 		
 	case COL_SLACK:
@@ -2388,29 +2395,23 @@ task_tree_add_column (GtkTreeView *tree,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_min_width (col, 70);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_slack_data_func,
-							 tree,
+							 GTK_TREE_VIEW (tree),
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_slack_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-		
-		gtk_tree_view_append_column (tree, col);
+		g_object_set_data (G_OBJECT (col), "id", "slack");
 		break;
 		
 	case COL_FINISH:
 		cell = planner_cell_renderer_date_new (FALSE);
-		/*g_signal_connect (cell,
-		  "edited",
-		  G_CALLBACK (task_tree_start_edited),
-		  tree);*/
 		g_signal_connect (cell,
 				  "show-popup",
 				  G_CALLBACK (task_tree_start_show_popup),
-				  tree);
+				  GTK_TREE_VIEW (tree));
 		
 		col = gtk_tree_view_column_new_with_attributes (title,
 								cell,
@@ -2420,13 +2421,10 @@ task_tree_add_column (GtkTreeView *tree,
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_finish_data_func,
-							 tree, NULL);
+							 GTK_TREE_VIEW (tree), NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_finish_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-
-		gtk_tree_view_append_column (tree, col);
+		g_object_set_data (G_OBJECT (col), "id", "finish");
 		break;
 
 	case COL_COST:
@@ -2435,17 +2433,15 @@ task_tree_add_column (GtkTreeView *tree,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_min_width (col, 70);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_cost_data_func,
-							 tree,
+							 GTK_TREE_VIEW (tree),
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_cost_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-
-		gtk_tree_view_append_column (tree, col);
+		g_object_set_data (G_OBJECT (col), "id", "cost");
 		break;
 
 	case COL_ASSIGNED_TO:
@@ -2454,28 +2450,41 @@ task_tree_add_column (GtkTreeView *tree,
 								cell,
 								NULL);
 		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_min_width (col, 70);
 		gtk_tree_view_column_set_cell_data_func (col,
 							 cell,
 							 task_tree_assigned_to_data_func,
-							 tree,
+							 GTK_TREE_VIEW (tree),
 							 NULL);
 		g_object_set_data (G_OBJECT (col),
 				   "data-func", task_tree_assigned_to_data_func);
-		g_object_set_data (G_OBJECT (col),
-				   "user-data", tree);
-
-		gtk_tree_view_append_column (tree, col);
+		g_object_set_data (G_OBJECT (col), "id", "assigned_to");
 		break;
 
 	default:
 		g_assert_not_reached ();
 	}
+
+	gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
+	
+	g_object_set_data (G_OBJECT (col), "user-data", GTK_TREE_VIEW (tree));
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tree), col);
+
+	if (expander) {
+		gtk_tree_view_set_expander_column (GTK_TREE_VIEW (tree), col);
+	}
+
+	g_signal_connect (col,
+			  "notify::width",
+			  G_CALLBACK (task_tree_column_notify_width_cb),
+			  GTK_TREE_VIEW (tree));
 }
 
 GtkWidget *
 planner_task_tree_new (PlannerWindow     *main_window,
 		       PlannerGanttModel *model, 
 		       gboolean           custom_properties,
+		       gboolean           add_newline,
 		       gint               first_column,
 		       ...)
 {
@@ -2483,8 +2492,9 @@ planner_task_tree_new (PlannerWindow     *main_window,
 	PlannerTaskTree     *tree;
 	PlannerTaskTreePriv *priv;
 	va_list              args;
-	gpointer             str;
+	const gchar         *title;
 	gint                 col;
+	gchar               *tmp;
 	
 	tree = g_object_new (PLANNER_TYPE_TASK_TREE, NULL);
 
@@ -2502,9 +2512,15 @@ planner_task_tree_new (PlannerWindow     *main_window,
 
 	col = first_column;
 	while (col != -1) {
-		str = va_arg (args, gpointer);
+		title = va_arg (args, gchar *);
 
-		task_tree_add_column (GTK_TREE_VIEW (tree), col, str);
+		if (add_newline) {
+			tmp = g_strdup_printf ("\n%s", (gchar *) title);
+			task_tree_add_column (tree, col, tmp);
+			g_free (tmp);
+		} else {
+			task_tree_add_column (tree, col, title);
+		}
 		
 		col = va_arg (args, gint);
 	}
@@ -3014,6 +3030,8 @@ planner_task_tree_indent_task (PlannerTaskTree *tree)
 			planner_window_get_cmd_manager (priv->main_window),
 			_("Indent tasks"));
 	}
+
+	task_tree_block_selection_changed (tree);
 		
 	for (l = indent_tasks; l; l = l->next) {
 		TaskCmdMove *cmd;
@@ -3041,7 +3059,6 @@ planner_task_tree_indent_task (PlannerTaskTree *tree)
 	path = planner_gantt_model_get_path_from_task (PLANNER_GANTT_MODEL (model), 
 						       indent_tasks->data);
 
-	task_tree_block_selection_changed (tree);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
 	gtk_tree_selection_select_path (selection, path);
 	task_tree_unblock_selection_changed (tree);
@@ -3568,6 +3585,19 @@ planner_task_tree_set_highlight_critical (PlannerTaskTree *tree,
 	gtk_widget_queue_draw (GTK_WIDGET (tree));
 }
 
+void
+planner_task_tree_set_nonstandard_days (PlannerTaskTree *tree,
+					  gboolean         nonstandard_days)
+{
+	g_return_if_fail (PLANNER_IS_TASK_TREE (tree));
+
+	if (tree->priv->nonstandard_days == nonstandard_days) {
+		return;
+	}
+	tree->priv->nonstandard_days = nonstandard_days;
+	gtk_widget_queue_draw (GTK_WIDGET (tree));
+}
+
 gboolean
 planner_task_tree_get_highlight_critical (PlannerTaskTree *tree)
 {
@@ -3576,6 +3606,15 @@ planner_task_tree_get_highlight_critical (PlannerTaskTree *tree)
 	return tree->priv->highlight_critical;
 }
 
+gboolean
+planner_task_tree_get_nonstandard_days (PlannerTaskTree *tree)
+{
+	g_return_val_if_fail (PLANNER_IS_TASK_TREE (tree), FALSE);
+	
+	return tree->priv->nonstandard_days;
+}
+
+
 void
 planner_task_tree_set_anchor (PlannerTaskTree *tree, GtkTreePath *anchor)
 {
